# pymime

A python mime types lib that list all known mime types and provide related tools (Such as download the latest mime type defintions and generate python file)

# Install

Install from pypi: `pip install pymime`

# Usage

    import mime

    contentType = mime.APPLICATION_JSON     # application/json

